#

##

##

###

##

##

    	Reverse Proxy
    		# demux, demultiplexer
    		# distributary
    		# reverse proxies
    		# walls
    		# onramps
    		# frontend

    	summary

    	install
    		HA Proxy
    			sudo apt install haproxy

    	build & start

    			sudo python3 start.proc.py demux build-certs
    			sudo python3 start.proc.py demux start

    	climate
    		This is where the configuration is.